@@ -1,22 +1,29 @@
 /*
  * Cogl
  *
- * An object oriented GL/GLES Abstraction/Utility Layer
+ * A Low Level GPU Graphics and Utilities API
  *
  * Copyright (C) 2011, 2013 Intel Corporation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+ * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+ * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  *
  *
  */
@@ -35,12 +42,42 @@
 #include "cogl1-context.h"
 #include "cogl-closure-list-private.h"
 #include "cogl-poll-private.h"
+#include "cogl-gtype-private.h"
+
+#ifdef COGL_HAS_X11_SUPPORT
+#include "cogl-xlib-renderer.h"
+#endif
 
 static void _cogl_onscreen_free (CoglOnscreen *onscreen);
 
-COGL_OBJECT_DEFINE_WITH_CODE (Onscreen, onscreen,
-                              _cogl_onscreen_class.virt_unref =
-                              _cogl_framebuffer_unref);
+COGL_OBJECT_DEFINE_WITH_CODE_GTYPE (Onscreen, onscreen,
+                                    _cogl_onscreen_class.virt_unref =
+                                    _cogl_framebuffer_unref);
+COGL_GTYPE_DEFINE_CLASS (Onscreen, onscreen,
+                         COGL_GTYPE_IMPLEMENT_INTERFACE (framebuffer));
+
+static gpointer
+cogl_dummy_copy (gpointer data)
+{
+  return data;
+}
+
+static void
+cogl_dummy_free (gpointer data)
+{
+}
+
+COGL_GTYPE_DEFINE_BOXED (FrameClosure, frame_closure,
+                         cogl_dummy_copy,
+                         cogl_dummy_free);
+COGL_GTYPE_DEFINE_BOXED (OnscreenResizeClosure,
+                         onscreen_resize_closure,
+                         cogl_dummy_copy,
+                         cogl_dummy_free);
+COGL_GTYPE_DEFINE_BOXED (OnscreenDirtyClosure,
+                         onscreen_dirty_closure,
+                         cogl_dummy_copy,
+                         cogl_dummy_free);
 
 static void
 _cogl_onscreen_init_from_template (CoglOnscreen *onscreen,
@@ -414,18 +451,17 @@ cogl_x11_onscreen_get_window_xid (CoglOnscreen *onscreen)
 uint32_t
 cogl_x11_onscreen_get_visual_xid (CoglOnscreen *onscreen)
 {
-  CoglFramebuffer *framebuffer = COGL_FRAMEBUFFER (onscreen);
-  const CoglWinsysVtable *winsys = _cogl_framebuffer_get_winsys (framebuffer);
+  CoglContext *ctx = COGL_FRAMEBUFFER (onscreen)->context;
   XVisualInfo *visinfo;
   uint32_t id;
 
   /* This should only be called for xlib based onscreens */
-  _COGL_RETURN_VAL_IF_FAIL (winsys->xlib_get_visual_info != NULL, 0);
+  visinfo = cogl_xlib_renderer_get_visual_info (ctx->display->renderer);
+  if (visinfo == NULL)
+    return 0;
 
-  visinfo = winsys->xlib_get_visual_info ();
   id = (uint32_t)visinfo->visualid;
 
-  XFree (visinfo);
   return id;
 }
 #endif /* COGL_HAS_X11_SUPPORT */
