@@ -138,6 +138,9 @@
 #include <cogl/cogl-kms-renderer.h>
 #include <cogl/cogl-kms-display.h>
 #endif
+#if defined (COGL_HAS_EGL_PLATFORM_MIR_SUPPORT)
+#include <cogl/cogl-mir-renderer.h>
+#endif
 #ifdef COGL_HAS_WIN32_SUPPORT
 #include <cogl/cogl-win32-renderer.h>
 #endif
