@@ -385,11 +385,9 @@ paint_cb (void *user_data)
   for (l = compositor->outputs; l; l = l->next)
     {
       CoglandOutput *output = l->data;
-      CoglFramebuffer *fb = COGL_FRAMEBUFFER (output->onscreen);
+      CoglFramebuffer *fb = output->onscreen;
       GList *l2;
 
-      cogl_push_framebuffer (fb);
-
       cogl_framebuffer_clear4f (fb, COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
 
       cogl_primitive_draw (compositor->triangle,
@@ -402,13 +400,14 @@ paint_cb (void *user_data)
           if (surface->texture)
             {
               CoglTexture2D *texture = surface->texture;
-              cogl_set_source_texture (COGL_TEXTURE (texture));
-              cogl_rectangle (-1, 1, 1, -1);
+              CoglPipeline *pipeline =
+                cogl_pipeline_new (compositor->cogl_context);
+              cogl_pipeline_set_layer_texture (pipeline, 0, texture);
+              cogl_framebuffer_draw_rectangle (fb, pipeline, -1, 1, 1, -1);
+              cogl_object_unref (pipeline);
             }
         }
       cogl_onscreen_swap_buffers (COGL_ONSCREEN (fb));
-
-      cogl_pop_framebuffer ();
     }
 
   while (!wl_list_empty (&compositor->frame_callbacks))
@@ -446,42 +445,14 @@ surface_damaged (CoglandSurface *surface,
         wl_shm_buffer_get (surface->buffer_ref.buffer->resource);
 
       if (shm_buffer)
-        {
-          CoglPixelFormat format;
-          int stride = wl_shm_buffer_get_stride (shm_buffer);
-          const uint8_t *data = wl_shm_buffer_get_data (shm_buffer);
-
-          switch (wl_shm_buffer_get_format (shm_buffer))
-            {
-#if G_BYTE_ORDER == G_BIG_ENDIAN
-            case WL_SHM_FORMAT_ARGB8888:
-              format = COGL_PIXEL_FORMAT_ARGB_8888_PRE;
-              break;
-            case WL_SHM_FORMAT_XRGB8888:
-              format = COGL_PIXEL_FORMAT_ARGB_8888;
-              break;
-#elif G_BYTE_ORDER == G_LITTLE_ENDIAN
-            case WL_SHM_FORMAT_ARGB8888:
-              format = COGL_PIXEL_FORMAT_BGRA_8888_PRE;
-              break;
-            case WL_SHM_FORMAT_XRGB8888:
-              format = COGL_PIXEL_FORMAT_BGRA_8888;
-              break;
-#endif
-            default:
-              g_warn_if_reached ();
-              format = COGL_PIXEL_FORMAT_ARGB_8888;
-            }
-
-          cogl_texture_set_region (COGL_TEXTURE (surface->texture),
-                                   x, y, /* src_x/y */
-                                   x, y, /* dst_x/y */
-                                   width, height, /* dst_width/height */
-                                   width, height, /* width/height */
-                                   format,
-                                   stride,
-                                   data);
-        }
+        cogl_wayland_texture_set_region_from_shm_buffer (surface->texture,
+                                                         x, y,
+                                                         width,
+                                                         height,
+                                                         shm_buffer,
+                                                         x, y,
+                                                         0, /* level */
+                                                         NULL);
     }
 
   cogland_queue_redraw (surface->compositor);
@@ -634,7 +605,7 @@ cogland_surface_commit (struct wl_client *client,
       !region_is_empty (&surface->pending.damage))
     {
       CoglandRegion *region = &surface->pending.damage;
-      CoglTexture *texture = COGL_TEXTURE (surface->texture);
+      CoglTexture *texture = surface->texture;
 
       if (region->x2 > cogl_texture_get_width (texture))
         region->x2 = cogl_texture_get_width (texture);
@@ -885,7 +856,7 @@ cogland_compositor_create_output (CoglandCompositor *compositor,
                                         width_mm, height_mm);
   /* Eventually there will be an implicit allocate on first use so this
    * will become optional... */
-  fb = COGL_FRAMEBUFFER (output->onscreen);
+  fb = output->onscreen;
   if (!cogl_framebuffer_allocate (fb, &error))
     g_error ("Failed to allocate framebuffer: %s\n", error->message);
 
@@ -895,7 +866,8 @@ cogland_compositor_create_output (CoglandCompositor *compositor,
                                     NULL /* destroy */);
 
   cogl_onscreen_show (output->onscreen);
-  cogl_framebuffer_set_viewport (fb, -x, -y,
+  cogl_framebuffer_set_viewport (fb,
+                                 -x, -y,
                                  compositor->virtual_width,
                                  compositor->virtual_height);
 
