@@ -2,6 +2,10 @@
 
 #include <stdlib.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include "test-unit.h"
 #include "test-utils.h"
 
@@ -125,7 +129,7 @@ is_boolean_env_set (const char *variable)
   return ret;
 }
 
-void
+CoglBool
 test_utils_init (TestFlags requirement_flags,
                  TestFlags known_failure_flags)
 {
@@ -146,6 +150,11 @@ test_utils_init (TestFlags requirement_flags,
                 "$ make test-report");
   counter++;
 
+#ifdef HAVE_ALARM
+  /* Kill the test with SIGALRM if it takes more than this many seconds */
+  alarm (120);
+#endif
+
   if (is_boolean_env_set ("COGL_TEST_VERBOSE") ||
       is_boolean_env_set ("V"))
     cogl_test_is_verbose = TRUE;
@@ -204,6 +213,8 @@ test_utils_init (TestFlags requirement_flags,
     g_print ("WARNING: Missing required feature[s] for this test\n");
   else if (known_failure)
     g_print ("WARNING: Test is known to fail\n");
+
+  return (!missing_requirement && !known_failure);
 }
 
 void
@@ -298,7 +309,17 @@ void
 test_utils_check_pixel_rgb (CoglFramebuffer *test_fb,
                             int x, int y, int r, int g, int b)
 {
-  test_utils_check_pixel (test_fb, x, y, (r << 24) | (g << 16) | (b << 8));
+  g_return_if_fail (r >= 0);
+  g_return_if_fail (g >= 0);
+  g_return_if_fail (b >= 0);
+  g_return_if_fail (r <= 0xFF);
+  g_return_if_fail (g <= 0xFF);
+  g_return_if_fail (b <= 0xFF);
+
+  test_utils_check_pixel (test_fb, x, y,
+                          (((guint32) r) << 24) |
+                          (((guint32) g) << 16) |
+                          (((guint32) b) << 8));
 }
 
 void
