@@ -1,6 +1,13 @@
 #ifndef _TEST_UTILS_H_
 #define _TEST_UTILS_H_
 
+/* NB: This header is for private and public api testing and so
+ * we need consider that if we are testing the public api we should
+ * just include <cogl/cogl.h> but since that will only provide
+ * opaque typedefs we need to include the specific internal headers
+ * for testing private apis...
+ */
+#ifdef COGL_COMPILATION
 #include <cogl/cogl-context.h>
 #include <cogl/cogl-onscreen.h>
 #include <cogl/cogl-offscreen.h>
@@ -9,6 +16,10 @@
 #include <cogl/cogl-texture-2d-sliced.h>
 #include <cogl/cogl-meta-texture.h>
 #include <cogl/cogl-atlas-texture.h>
+#else
+#include <cogl/cogl.h>
+#endif
+
 #include <glib.h>
 
 /* We don't really care about functions that are defined without a
@@ -24,13 +35,14 @@ typedef enum _TestFlags
   TEST_REQUIREMENT_NPOT = 1<<2,
   TEST_REQUIREMENT_TEXTURE_3D = 1<<3,
   TEST_REQUIREMENT_TEXTURE_RECTANGLE = 1<<4,
-  TEST_REQUIREMENT_POINT_SPRITE = 1<<5,
-  TEST_REQUIREMENT_GLES2_CONTEXT = 1<<6,
-  TEST_REQUIREMENT_MAP_WRITE = 1<<7,
-  TEST_REQUIREMENT_GLSL = 1<<8,
-  TEST_REQUIREMENT_OFFSCREEN = 1<<9,
-  TEST_REQUIREMENT_FENCE = 1<<10,
-  TEST_REQUIREMENT_PER_VERTEX_POINT_SIZE = 1<<11
+  TEST_REQUIREMENT_TEXTURE_RG = 1<<5,
+  TEST_REQUIREMENT_POINT_SPRITE = 1<<6,
+  TEST_REQUIREMENT_GLES2_CONTEXT = 1<<7,
+  TEST_REQUIREMENT_MAP_WRITE = 1<<8,
+  TEST_REQUIREMENT_GLSL = 1<<9,
+  TEST_REQUIREMENT_OFFSCREEN = 1<<10,
+  TEST_REQUIREMENT_FENCE = 1<<11,
+  TEST_REQUIREMENT_PER_VERTEX_POINT_SIZE = 1<<12
 } TestFlags;
 
  /**
@@ -57,7 +69,7 @@ typedef enum {
 extern CoglContext *test_ctx;
 extern CoglFramebuffer *test_fb;
 
-void
+CoglBool
 test_utils_init (TestFlags requirement_flags,
                  TestFlags known_failure_flags);
 
@@ -70,8 +82,7 @@ test_utils_fini (void);
  * @width: width of texture in pixels.
  * @height: height of texture in pixels.
  * @flags: Optional flags for the texture, or %TEST_UTILS_TEXTURE_NONE
- * @internal_format: the #CoglPixelFormat to use for the GPU storage of the
- *    texture.
+ * @components: What texture components are required
  *
  * Creates a new #CoglTexture with the specified dimensions and pixel format.
  *
@@ -89,7 +100,7 @@ test_utils_texture_new_with_size (CoglContext *ctx,
                                   int width,
                                   int height,
                                   TestUtilsTextureFlags flags,
-                                  CoglPixelFormat internal_format);
+                                  CoglTextureComponents components);
 
 /*
  * test_utils_texture_new_from_data:
@@ -98,14 +109,6 @@ test_utils_texture_new_with_size (CoglContext *ctx,
  * @height: height of texture in pixels
  * @flags: Optional flags for the texture, or %TEST_UTILS_TEXTURE_NONE
  * @format: the #CoglPixelFormat the buffer is stored in in RAM
- * @internal_format: the #CoglPixelFormat that will be used for storing
- *    the buffer on the GPU. If COGL_PIXEL_FORMAT_ANY is given then a
- *    premultiplied format similar to the format of the source data will
- *    be used. The default blending equations of Cogl expect premultiplied
- *    color data; the main use of passing a non-premultiplied format here
- *    is if you have non-premultiplied source data and are going to adjust
- *    the blend mode (see cogl_material_set_blend()) or use the data for
- *    something other than straight blending.
  * @rowstride: the memory offset in bytes between the starts of
  *    scanlines in @data
  * @data: pointer the memory region where the source buffer resides
@@ -113,6 +116,13 @@ test_utils_texture_new_with_size (CoglContext *ctx,
  *
  * Creates a new #CoglTexture based on data residing in memory.
  *
+ * Note: If the given @format has an alpha channel then the data
+ * will be loaded into a premultiplied internal format. If you want
+ * to avoid having the source data be premultiplied then you can
+ * either specify that the data is already premultiplied or use
+ * test_utils_texture_new_from_bitmap which lets you explicitly
+ * request whether the data should internally be premultipled or not.
+ *
  * Return value: A newly created #CoglTexture or %NULL on failure
  */
 CoglTexture *
@@ -121,7 +131,6 @@ test_utils_texture_new_from_data (CoglContext *ctx,
                                   int height,
                                   TestUtilsTextureFlags flags,
                                   CoglPixelFormat format,
-                                  CoglPixelFormat internal_format,
                                   int rowstride,
                                   const uint8_t *data);
 
@@ -129,9 +138,12 @@ test_utils_texture_new_from_data (CoglContext *ctx,
  * test_utils_texture_new_from_bitmap:
  * @bitmap: A #CoglBitmap pointer
  * @flags: Optional flags for the texture, or %TEST_UTILS_TEXTURE_NONE
- * @internal_format: the #CoglPixelFormat to use for the GPU storage of the
- * texture
- * @error: A #CoglError to catch exceptional errors or %NULL
+ * @premultiplied: Whether the texture should hold premultipled data.
+ *                 (if the bitmap already holds premultiplied data
+ *                 and %TRUE is given then no premultiplication will
+ *                 be done. The data will be premultipled while
+ *                 uploading if the bitmap has an alpha channel but
+ *                 does not already have a premultiplied format.)
  *
  * Creates a #CoglTexture from a #CoglBitmap.
  *
@@ -140,7 +152,7 @@ test_utils_texture_new_from_data (CoglContext *ctx,
 CoglTexture *
 test_utils_texture_new_from_bitmap (CoglBitmap *bitmap,
                                     TestUtilsTextureFlags flags,
-                                    CoglPixelFormat internal_format);
+                                    CoglBool premultiplied);
 
 /*
  * test_utils_check_pixel:
