@@ -193,6 +193,9 @@ validate_result (CoglFramebuffer *framebuffer, int y_offset)
           cull_front = TRUE;
           cull_back = TRUE;
           break;
+
+        default:
+          g_assert_not_reached ();
         }
 
       if (FRONT_WINDING (draw_num) == COGL_WINDING_CLOCKWISE)
@@ -271,7 +274,6 @@ make_texture (void)
                                           TEXTURE_SIZE,
                                           TEST_UTILS_TEXTURE_NO_ATLAS,
                                           COGL_PIXEL_FORMAT_RGBA_8888,
-                                          COGL_PIXEL_FORMAT_ANY,
                                           TEXTURE_SIZE * 4,
                                           tex_data);
 
@@ -296,9 +298,8 @@ test_backface_culling (void)
   tex = test_utils_texture_new_with_size (test_ctx,
                                           state.width, state.height,
                                           TEST_UTILS_TEXTURE_NO_SLICING,
-                                          COGL_PIXEL_FORMAT_ANY); /* internal
-                                                                     format */
-  state.offscreen = COGL_FRAMEBUFFER (cogl_offscreen_new_with_texture (tex));
+                                          COGL_TEXTURE_COMPONENTS_RGBA);
+  state.offscreen = cogl_offscreen_new_with_texture (tex);
   state.offscreen_tex = tex;
 
   paint (&state);
