@@ -7,19 +7,19 @@ test_framebuffer_get_bits (void)
 {
   CoglTexture2D *tex_a =
     cogl_texture_2d_new_with_size (test_ctx,
-                                   16, 16, /* width/height */
-                                   COGL_PIXEL_FORMAT_A_8);
+                                   16, 16); /* width/height */
   CoglOffscreen *offscreen_a =
-    cogl_offscreen_new_with_texture (COGL_TEXTURE (tex_a));
-  CoglFramebuffer *fb_a = COGL_FRAMEBUFFER (offscreen_a);
+    cogl_offscreen_new_with_texture (tex_a);
+  CoglFramebuffer *fb_a = offscreen_a;
   CoglTexture2D *tex_rgba =
     cogl_texture_2d_new_with_size (test_ctx,
-                                   16, 16, /* width/height */
-                                   COGL_PIXEL_FORMAT_RGBA_8888);
+                                   16, 16); /* width/height */
   CoglOffscreen *offscreen_rgba =
-    cogl_offscreen_new_with_texture (COGL_TEXTURE (tex_rgba));
-  CoglFramebuffer *fb_rgba = COGL_FRAMEBUFFER (offscreen_rgba);
+    cogl_offscreen_new_with_texture (tex_rgba);
+  CoglFramebuffer *fb_rgba = offscreen_rgba;
 
+  cogl_texture_set_components (tex_a,
+                               COGL_TEXTURE_COMPONENTS_A);
   cogl_framebuffer_allocate (fb_a, NULL);
   cogl_framebuffer_allocate (fb_rgba, NULL);
 
