@@ -26,18 +26,16 @@ test_texture_no_allocate (void)
 
   /* Try to create an atlas texture that is too big so it will
    * internally be freed without allocating */
-  texture = COGL_TEXTURE (
+  texture =
     cogl_atlas_texture_new_from_data (test_ctx,
                                       BIG_TEX_WIDTH,
                                       BIG_TEX_HEIGHT,
                                       /* format */
                                       COGL_PIXEL_FORMAT_RGBA_8888_PRE,
-                                      /* internal format */
-                                      COGL_PIXEL_FORMAT_ANY,
                                       /* rowstride */
                                       BIG_TEX_WIDTH * 4,
                                       tex_data,
-                                      &error));
+                                      &error);
 
   g_free (tex_data);
 
@@ -50,18 +48,16 @@ test_texture_no_allocate (void)
     cogl_object_unref (texture);
 
   /* Try to create a sliced texture without allocating it */
-  texture = COGL_TEXTURE (
+  texture =
     cogl_texture_2d_sliced_new_with_size (test_ctx,
                                           BIG_TEX_WIDTH,
                                           BIG_TEX_HEIGHT,
-                                          COGL_TEXTURE_MAX_WASTE,
-                                          COGL_PIXEL_FORMAT_RGBA_8888_PRE));
+                                          COGL_TEXTURE_MAX_WASTE);
   cogl_object_unref (texture);
 
   /* 2D texture */
   texture_2d = cogl_texture_2d_new_with_size (test_ctx,
-                                              64, 64,
-                                              COGL_PIXEL_FORMAT_RGBA_8888_PRE);
+                                              64, 64);
   cogl_object_unref (texture_2d);
 
   /* 3D texture */
@@ -69,8 +65,7 @@ test_texture_no_allocate (void)
     {
       CoglTexture3D *texture_3d =
         cogl_texture_3d_new_with_size (test_ctx,
-                                       64, 64, 64,
-                                       COGL_PIXEL_FORMAT_RGBA_8888_PRE);
+                                       64, 64, 64);
       cogl_object_unref (texture_3d);
     }
 
@@ -79,9 +74,7 @@ test_texture_no_allocate (void)
     {
       CoglTextureRectangle *texture_rect =
         cogl_texture_rectangle_new_with_size (test_ctx,
-                                              64, 64,
-                                              COGL_PIXEL_FORMAT_RGBA_8888_PRE,
-                                              NULL /* error */);
+                                              64, 64);
       cogl_object_unref (texture_rect);
     }
 }
